#!/usr/bin/env python3

"""[WORKERNAME] worker for the ACT platform

Copyright YEAR YOU <YOU.YOU2@YOUR.EMAIL>

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
"""


import sys
import traceback
from logging import error
from typing import Text

import act.api
from act.api.libs import cli

import act
from act.workers.libs import worker

WORKER_NAME = "TODO"


def process(api: act.api.Act, output_format: Text = "json") -> None:
    """Read queries from stdin"""

    for query in sys.stdin:
        query = query.strip()

        if not query:
            continue

        # INSERT PROCESSOR CODE HERE
        #
        # https://github.com/mnemonic-no/act-api-python/blob/master/README.md
        #
        # consider using helpers from act.api.helpers such as handle_fact etc.
        #
        # several workers are available under https://github.com/mnemonic-no/act-workers/tree/master/act/workers


def main() -> None:
    """Main function"""
    # Look for default ini file in "/etc/actworkers.ini" and
    # ~/config/actworkers/actworkers.ini (or replace .config with
    # $XDG_CONFIG_DIR if set)
    args = cli.handle_args(worker.parseargs(WORKER_NAME))
    actapi = worker.init_act(args)

    process(actapi, args.output_format)


def main_log_error() -> None:
    "Main function wrapper. Log all exceptions to error"
    try:
        main()
    except Exception:
        error("Unhandled exception: {}".format(traceback.format_exc()))
        raise


if __name__ == "__main__":
    main_log_error()



"""Setup script for the python-act library module"""

from os import path

from setuptools import setup

# read the contents of your README file
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, "README.md"), "rb") as f:
    long_description = f.read().decode("utf-8")

setup(
    name="act-workers",
    version="2.1.0",
    author="mnemonic AS",
    zip_safe=True,
    author_email="opensource@mnemonic.no",
    description="ACT workers",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="MIT",
    keywords="ACT, mnemonic",
    entry_points={
        "console_scripts": [
            "act-argus-case = act.workers.argus_case:main_log_error",
            "act-attack = act.workers.attack:main_log_error",
            "act-country-regions = act.workers.country_regions:main_log_error",
            "act-fact-chain-helper = act.workers.fact_chain_helper:main_log_error",
            "act-feed = act.workers.act_feed:main_log_error",
            "act-hybrid-analysis-feed = act.workers.hybrid_analysis_feed:main_log_error",
            "act-ip-asn-history = act.workers.ip_asn_history:main_log_error",
            "act-ip-filter= act.workers.ip_filter:main_log_error",
            "act-isight = act.workers.isight:main_log_error",
            "act-misp-feeds = act.workers.misp_feeds:main_log_error",
            "act-mnemonic-pdns = act.workers.mnemonic_pdns:main_log_error",
            "act-scio = act.workers.scio:main_log_error",
            "act-search-graph = act.workers.search_graph:main_log_error",
            "act-shadowserver-asn = act.workers.shadowserver_asn:main_log_error",
            "act-shadowserver-enrich = act.workers.shadowserver_enrich:main_log_error",
            "act-ta-helper = act.workers.ta_helper:main_log_error",
            "act-thaicert = act.workers.thaicert:main_log_error",
            "act-tool-alias = act.workers.tool_alias:main_log_error",
            "act-uploader = act.workers.generic_uploader:main_log_error",
            "act-url-shorter-unpack = act.workers.url_shorter_unpack:main_log_error",
            "act-veris = act.workers.veris:main_log_error",
            "act-vt = act.workers.vt:main_log_error",
            "act-worker-config = act.workers.worker_config:main",
        ]
    },
    # Include ini-file(s) from act/workers/etc
    package_data={"act.workers": ["etc/*.ini"]},
    packages=["act.workers", "act.workers.libs"],
    # https://packaging.python.org/guides/packaging-namespace-packages/#pkgutil-style-namespace-packages
    # __init__.py under all packages under in the act namespace must contain exactly string:
    # __path__ = __import__('pkgutil').extend_path(__path__, __name__)
    namespace_packages=["act"],
    url="https://github.com/mnemonic-no/act-workers",
    install_requires=[
        "act-api>=2.1.0,<2.2.0",
        "act-types>=2.1.0,<2.2.0",
        "caep",
        "pid",
        "requests",
        "RashlyOutlaid>=0.19",
        "virustotal-api",
        "dateparser",
        "pyattck>=5.2.0",
    ],
    python_requires=">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, <4",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Topic :: Utilities",
        "License :: OSI Approved :: ISC License (ISCL)",
    ],
)
